@@ -2,15 +2,17 @@ package Text::WikiFormat;
 
 use strict;
 
-use Carp;
 use URI;
+use Carp ();
 use URI::Escape;
+use Text::WikiFormat::Blocks;
+use Scalar::Util qw( blessed reftype );
 
 use vars qw( $VERSION %tags $indent );
-$VERSION = 0.72;
+$VERSION = '0.75';
 
-$indent = qr/^(?:\t+|\s{4,})/;
-%tags   = (
+$indent  = qr/^(?:\t+|\s{4,})/;
+%tags    = (
 	indent		=> qr/^(?:\t+|\s{4,})/,
 	newline		=> '<br />',
 	link		=> \&make_html_link,
@@ -45,55 +47,60 @@ $indent = qr/^(?:\t+|\s{4,})/;
 	blockorder               =>
 		[qw( header line ordered unordered code paragraph )],
 	extended_link_delimiters => [qw( [ ] )],
+
+	schemas => [ qw( http https ftp mailto gopher ) ],
 );
 
 sub process_args
 {
 	my $self = shift;
-	my $name = @_ == 1 ? shift : 'wikiformat';
-	return ( as => $name, @_ );
+
+	return as => 'wikiformat' unless @_;
+	return as => shift        if     @_ == 1;
+	return as => 'wikiformat',       @_;
 }
 
 sub default_opts
 {
 	my ($class, $args) = @_;
 
-	my %defopts = ( implicit_links => 1, map { $_ => delete $args->{ $_ } }
-		qw( prefix extended implicit_links) );
-
-	return %defopts;
+	return
+		implicit_links => 1,
+		map { $_ => delete $args->{ $_ } }
+		    qw( prefix extended implicit_links absolute_links );
 }
 
 sub merge_hash
 {
 	my ($from, $to) = @_;
+
 	while (my ($key, $value) = each %$from)
 	{
-		if (UNIVERSAL::isa( $value, 'HASH' ))
+		if ((reftype( $value ) || '' ) eq 'HASH' )
 		{
 			$to->{$key} = {} unless defined $to->{$key};
 			merge_hash( $value, $to->{$key} );
+			next;
 		}
-		else
-		{
-			$to->{$key} = $value;
-		}
+
+		$to->{$key} = $value;
 	}
 }
 
 sub import
 {
-	my $class = shift;
+	my $class   = shift;
 	return unless @_;
 
 	my %args    = $class->process_args( @_ );
 	my %defopts = $class->default_opts( \%args );
 
-	my $caller = caller();
-	my $name   = delete $args{as};
+	my $caller  = caller();
+	my $name    = delete $args{as};
 
 	no strict 'refs';
-	*{ $caller . "::$name" } = sub {
+	*{ $caller . "::$name" } = sub
+	{
 		my ($text, $tags, $opts) = @_;
 
 		$tags ||= {};
@@ -111,17 +118,22 @@ sub import
 sub format
 {
 	my ($text, $newtags, $opts) = @_;
-	$opts    ||= { prefix => '', extended => 0, implicit_links => 1 };
+
+	$opts    ||=
+	{
+		prefix => '', extended => 0, implicit_links => 1, absolute_links => 0
+	};
+
 	my %tags   = %tags;
 
 	merge_hash( $newtags, \%tags )
-		if defined $newtags and UNIVERSAL::isa( $newtags, 'HASH' );
+		if defined $newtags and ( reftype( $newtags ) || '' ) eq 'HASH';
 	check_blocks( \%tags )
 		if exists $newtags->{blockorder} or exists $newtags->{blocks};
 
 	my @blocks =  find_blocks( $text,     \%tags, $opts );
-	@blocks    = merge_blocks( \@blocks,  \%tags, $opts );
-	@blocks    =  nest_blocks( \@blocks,  \%tags, $opts );
+	@blocks    = merge_blocks( \@blocks                 );
+	@blocks    =  nest_blocks( \@blocks                 );
 	return     process_blocks( \@blocks,  \%tags, $opts );
 }
 
@@ -152,7 +164,7 @@ sub find_blocks
 sub start_block
 {
 	my ($text, $tags, $opts) = @_;
-	return { type => 'end', level => 0 } unless $text;
+	return new_block( 'end', level => 0 ) unless $text;
 
 	for my $block (@{ $tags->{blockorder} })
 	{
@@ -176,59 +188,35 @@ sub start_block
 
 		next unless $marker_removed;
 
-		return {
-			args => [ grep { defined } $1, $2, $3, $4, $5, $6, $7, $8, $9 ],
-			type => $block,
-			text => $block eq 'code' ? $line : format_line($line, $tags, $opts),
-			level=> $level || 0,
-		};
+		return new_block( $block,
+			args  => [ grep { defined } $1, $2, $3, $4, $5, $6, $7, $8, $9 ],
+			level => $level || 0,
+			opts  => $opts,
+			text  => $line,
+			tags  => $tags,
+		);
 	}
 }
 
-sub merge_blocks
+# merge_blocks() and nest_blocks()
+BEGIN
 {
-	my ($blocks, $tags, $opts) = @_;
-
-	my @merged;
-	for my $block (@$blocks)
+	for my $op (qw( merge nest ))
 	{
-		if (@merged and $block->{type} eq $merged[-1]{type}
-			and $block->{level} == $merged[-1]{level})
+		no strict 'refs';
+		*{ $op . '_blocks' } = sub
 		{
-			push @{ $merged[-1]{text} }, $block->{text};
-			push @{ $merged[-1]{args} }, $block->{args};
-			next;
-		}
+			my $blocks    = shift;
+			my @processed = shift @$blocks;
 
-		push @merged, {
-			text  => [ $block->{text} ],
-			type  => $block->{type},
-			level => $block->{level},
-			args  => [ $block->{args} ],
+			for my $block (@$blocks)
+			{
+				push @processed, $processed[-1]->$op( $block );
+			}
+	
+			return @processed;
 		};
 	}
-
-	return @merged;
-}
-
-sub nest_blocks
-{
-	my ($blocks, $tags, $opts) = @_;
-	my @merged;
-
-	for my $block (@$blocks)
-	{
-		if (@merged and $tags->{nests}{ $block->{type} }
-			and $tags->{nests}{ $merged[-1]{type} }
-			and $block->{level} > $merged[-1]{level})
-		{
-			push @{ $merged[-1]{text} }, $block;
-			next;
-		}
-		push @merged, $block;
-	}
-
-	return @merged;
 }
 
 sub process_blocks
@@ -239,7 +227,7 @@ sub process_blocks
 	for my $block (@$blocks)
 	{
 		push @open, process_block( $block, $tags, $opts )
-			unless $block->{type} eq 'end';
+			unless $block->type() eq 'end';
 	}
 
 	return join('', @open);
@@ -250,24 +238,25 @@ sub process_block
 	my ($block, $tags, $opts) = @_;
 
 	my ($start, $end, $start_line, $end_line, $between)
-		= @{ $tags->{ $block->{type} } };
+		= @{ $tags->{ $block->type() } };
 
 	my @text;
 
-	for my $line (@{ $block->{text} })
+	for my $line ( $block->formatted_text() )
 	{
-		if (UNIVERSAL::isa( $line, 'HASH' ))
+		if (blessed( $line ))
 		{
 			my $prev_end = pop @text || ();
 			push @text, process_block( $line, $tags, $opts ), $prev_end;
 			next;
 		}
 
-		if (UNIVERSAL::isa( $start_line, 'CODE' ))
+		if ((reftype( $start_line ) || '' ) eq 'CODE' )
 		{
 			(my $start_line, $line, $end_line) = 
-				$start_line->( $line, $block->{level}, 
-				@{ shift @{ $block->{args} } }, $tags, $opts);
+				$start_line->(
+					$line, $block->level(), $block->shift_args(), $tags, $opts
+				);
 			push @text, $start_line, $line, $end_line;
 		}
 		else
@@ -381,26 +370,42 @@ sub format_line
 	return $text;
 }
 
+sub find_innermost_balanced_pair
+{
+	my ($text, $open, $close) = @_;
+
+	my $start_pos             = rindex( $text, $open              );
+	return if $start_pos == -1;
+
+	my $end_pos               =  index( $text, $close, $start_pos );
+	return if $end_pos == -1;
+
+	my $open_length           = length( $open );
+	my $close_length          = length( $close );
+	my $close_pos             = $end_pos + $close_length;
+	my $enclosed_length       = $close_pos - $start_pos;
+
+	my $enclosed_atom        = substr( $text, $start_pos, $enclosed_length );
+	return substr( $enclosed_atom, $open_length, 0 - $close_length ),
+	       substr( $text, 0, $start_pos ),
+		   substr( $text, $close_pos );
+}
+
 sub find_extended_links
 {
 	my ($text, $tags, $opts) = @_;
 
+    my $schemas = join('|', @{$tags->{schemas}});
+    $text =~ s!(\s+)(($schemas):\S+)!$1 . $tags->{link}->($2, $opts)!egi
+	    if $opts->{absolute_links};
+
 	my ($start, $end) = @{ $tags->{extended_link_delimiters} };
 
-	my $position = 0;
-	while (1)
+	while (my @pieces = find_innermost_balanced_pair( $text, $start, $end ) )
 	{
-		my $open       = index $text, $start, $position;
-		last if $open  == -1;
-		my $close      = index $text, $end, $open;
-		last if $close == -1;
-
-		my $text_start = $open + length $start;
-		my $extended   = substr $text, $text_start, $close - $text_start;
-
-		$extended  = $tags->{link}->( $extended, $opts );
-		substr $text, $open, $close - $open + length $end, $extended;
-		$position += length $extended;
+		my ($tag, $before, $after) = map { defined $_ ? $_ : '' } @pieces;
+		my $extended               = $tags->{link}->( $tag, $opts ) || '';
+		$text                      = $before . $extended . $after;
 	};
 
 	return $text;
@@ -456,11 +461,11 @@ Text::WikiFormat - module for translating Wiki formatted text into other formats
 
 =head1 DESCRIPTION
 
-The original Wiki web site was intended to have a very simple interface to
-edit and to add pages.  Its formatting rules are simple and easy to use.  They
-are also easily translated into other, more complicated markup languages with
-this module.  It creates HTML by default, but can be extended to produce valid
-POD, DocBook, XML, or any other format imaginable.
+The original Wiki web site had a very simple interface to edit and to add
+pages.  Its formatting rules are simple and easy to use.  They are also easy to
+translate into other, more complicated markup languages with this module.  It
+creates HTML by default, but can produce valid POD, DocBook, XML, or any other
+format imaginable.
 
 The most important function is C<format()>.  It is not exported by default.
 
@@ -469,75 +474,79 @@ The most important function is C<format()>.  It is not exported by default.
 C<format()> takes one required argument, the text to convert, and returns the
 converted text.  It allows two optional arguments.  The first is a reference to
 a hash of tags.  Anything passed in here will override the default tag
-behavior.  These tags are described later.  The second argument is a hash
-reference of options.  There are currently limited to:
+behavior.  The second argument is a hash reference of options.  They are
+currently:
 
 =over 4
 
 =item * prefix
 
 The prefix of any links.  In HTML mode, this is the path to the Wiki.  The
-actual linked item itself will be appended to the prefix.  This is used to
+actual linked item itself will be appended to the prefix.  This is useful to
 create full URIs:
 
 	{ prefix => 'http://example.com/wiki.pl?page=' }
 
 =item * extended
 
-A boolean flag, false by default, to use extended linking semantics.  This is
-stolen from the Everything Engine (L<http://everydevel.com/>), where links are
-marked by square brackets.  An optional title may occur after the link target,
-preceded by an open pipe.  That is to say, these are valid extended
-links:
+A boolean flag, false by default, to use extended linking semantics.  This
+comes from the Everything Engine (L<http:E<sol>E<sol>everydevel.comE<sol>>),
+which marks links with square brackets.  An optional title may occur after the
+link target, preceded by an open pipe.  These are valid extended links:
 
 	[a valid link]
 	[link|title]
 
-Where the linking semantics of the destination format allow it, the title will
-be displayed instead of the URI.  In HTML terms, the title is the content of an
-A element (not the content of its HREF attribute).
+Where the linking semantics of the destination format allow it, the result will
+display the title instead of the URI.  In HTML terms, the title is the content
+of an C<A> element (not the content of its C<HREF> attribute).
 
 You can use delimiters other than single square brackets for marking extended
-links, by passing a value for C<extended_link_delimiters> in the C<%tags> hash
-when calling C<format> (see below for details).
+links by passing a value for C<extended_link_delimiters> in the C<%tags> hash
+when calling C<format>.
 
 =item * implicit_links
 
-A boolean flag, true by default, to cause links to be created wherever a
-StudlyCapsString is seen.  Note that if you disable this flag, you'll most
-likely be wanting to enable the C<extended> one also, or there will be no way
-of creating links in your documents.  To disable it, use the pair:
+A boolean flag, true by default, to create links from StudlyCapsStringsNote
+that if you disable this flag, you should probably enable the C<extended> one
+also, or there will be no way of creating links in your documents.  To disable
+it, use the pair:
 
 	{ implicit_links => 0 }
 
 =item * absolute_links
 
 A boolean flag, false by default, which treats any links that are absolute URIs
-(such as http://www.cpan.org/) to be treated specially. Any prefix will not
-apply and the URIs aren't quoted. Must be used in conjunction with the
-C<extended> option for the link to be detected.
+(such as http://www.cpan.org/) specially. Any prefix will not apply and the
+URIs aren't quoted. Use this in conjunction with the C<extended> option to
+detect the link.
 
-This uses the L<URI> module to determine if links are absolute.  See the
-documentation for C<URI::schema> for the gory details of what is and isn't a
-valid schema.  C<http://>, C<ftp://>, C<mailto://>, and C<gopher://> all
-qualify.
+A link is any text that starts with a known schema followed by a colon and one
+or more non-whitespace characters.  This is a distinct subset of what L<URI>
+recognizes as a URI, but is a good first-order approximation.  If you need to
+recognize more complex URIs, use the standard wiki formatting explained
+earlier.
+
+The recognized schemas are those defined in the C<schema> value in the C<%tags>
+hash. The defaults are C<http>, C<https>, C<ftp>, C<mailto>, and C<gopher>.
+
+=back
 
 =head2 Wiki Format
 
 Wiki formatting is very simple.  An item wrapped in three single quotes is
-marked as B<strong>.  An item wrapped in two single quotes is marked as
-I<emphasized>.  Any word with multiple CapitalLetters (e. g., StudlyCaps) will
-be turned into a link.  Four or more hyphen characters at the start of a line
-create a horizontal line.  Newlines are translated into the appropriate tag.
-Headers are marked with matching equals signs around the header text -- the
-more signs, the lesser the header.
+B<strong>.  An item wrapped in two single quotes is I<emphasized>.  Any word
+with multiple CapitalLetters (e. g., StudlyCaps) will become a link.  Four or
+more hyphen characters at the start of a line create a horizontal line.
+Newlines turn into the appropriate tags.  Headers are matching equals signs
+around the header text -- the more signs, the lesser the header.
 
-Lists are indented by one tab or four spaces, by default.  Indentation may be
-disabled.  Lists can be unordered, where each item has its own bullet point.
-These are marked by a leading asterisk and space.  They can also be ordered,
-where any combination of one or more alphanumeric characters can be followed by
-a period and an optional space.  Any indented text without either marking is
-considered to be code, and is handled literally.  Lists can be nested.
+Lists are indented text, by one tab or four spaces by default.  You may disable
+indentation.  In unordered lists, where each item has its own bullet point,
+each item needs a leading asterisk and space.  Ordered lists consist of items
+marked with combination of one or more alphanumeric characters followed by a
+period and an optional space.  Any indented text without either marking is
+code, handled literally.  You can nest lists.
 
 The following is valid Wiki formatting, with an extended link as marked.
 
@@ -566,12 +575,12 @@ The following is valid Wiki formatting, with an extended link as marked.
 
 If you'd like to make your life more convenient, you can optionally import a
 subroutine that already has default tags and options set up.  This is
-especially handy if you will be using a prefix:
+especially handy if you use a prefix:
 
 	use Text::WikiFormat prefix => 'http://www.example.com/';
 	wikiformat( 'some text' );
 
-tags are interpreted as, well, tags, except for four special keys:
+Tags are interpreted as, well, tags, except for five special keys:
 
 =over 4
 
@@ -581,12 +590,14 @@ tags are interpreted as, well, tags, except for four special keys:
 
 =item * C<implicit_links>, interpreted as the flag to control implicit links
 
+=item * C<absolute_links>, interpreted as the flag to control absolute links
+
 =item * C<as>, interpreted as an alias for the imported function
 
 =back
 
-Use the C<as> flag to control the name by which the imported function is
-called.  For example,
+Use the C<as> flag to control the name by which your code calls the imported
+functionFor example,
 
 	use Text::WikiFormat as => 'formatTextInWikiStyle';
 	formatTextInWikiStyle( 'some text' );
@@ -595,17 +606,17 @@ You might choose a better name, though.
 
 The calling semantics are effectively the same as those of the format()
 function.  Any additional tags or options to the imported function will
-override the defaults.  In this example:
+override the defaults.  This code:
 
 	use Text::WikiFormat as => 'wf', extended => 0;
 	wf( 'some text', {}, { extended => 1 });
 
-extended links will be enabled, though the default is to disable them.
+enables extended links, though the default is to disable them.
 
-This feature was suggested by Tony Bowden E<lt>tony@kasei.comE<gt>, but all
+Tony Bowden E<lt>tony@kasei.comE<gt> suggested this feature, but all
 implementation blame rests solely with me.  Kate L Pugh
-(E<lt>kake@earth.liE<gt>) pointed out that it didn't work, with tests, so it's
-fixed now.
+(E<lt>kake@earth.liE<gt>) pointed out that it didn't work, with tests.  It
+works now.
 
 =head1 GORY DETAILS
 
@@ -617,11 +628,11 @@ lists, which are made up of lines and can also contain other lists.
 =head3 Line items
 
 There are two classes of line items: simple tags, and tags that contain data.
-The simple tags are C<newline> and C<line>.  A newline is inserted whenever a
-newline character (C<\n>) is encountered.  A line is inserted whenever four or
-more dash characters (C<---->) occur at the start of a line.  No whitespace is
-allowed.  These default to the E<lt>brE<gt> and E<lt>hrE<gt> HTML tags,
-respectively.  To override either, simply pass tags such as:
+The simple tags are C<newline> and C<line>.  The module inserts a newline tag
+whenever it encounters a newline character (C<\n>).  It inserts a line tag
+whenever four or more dash characters (C<---->) occur at the start of a line.
+No whitespace is allowed.  These default to the E<lt>brE<gt> and E<lt>hrE<gt>
+HTML tags, respectively.  To override either, simply pass tags such as:
 
 	my $html = format($text, { newline => "\n" });
 
@@ -629,7 +640,7 @@ The three line items are more complex, and require subroutine references. This
 category includes the C<strong> and C<emphasized> tags as well as C<link>s.
 The first argument passed to the subref will be the data found in between the
 marks.  The second argument is the $opts hash reference.  The default action
-for a strong tag can be reimplemented with this syntax:
+for a strong tag is equivalent to:
 
 	my $html = format($text, { strong => sub { "<b>$_[0]</b>" } });
 
@@ -655,59 +666,59 @@ the tags as:
 
 	my $html = format( $text, { extended_link_delimiters => [ '[[', ']]' ] });
 
-This will allow you to use double square brackets as UseMod supports:
+This allows you to use double square brackets as UseMod supports:
 
 	[[an extended link]]
 	[[a titled extended link|title]]
 
 =head3 Blocks
 
-Five block types are recognized by default:  C<paragraph>, C<header>, C<code>,
-C<unordered>, and C<ordered>.  Each of these is I<usually> marked by
-indentation, either one or more tabs or four or more whitespace characters.
-(This does not include newlines, however.)  Any line that does not fall in any
-of these three categories is automatically put in a C<paragraph> list.
+There are five default block types: C<paragraph>, C<header>, C<code>,
+C<unordered>, and C<ordered>.  The parser usually finds these by indentation,
+either one or more tabs or four or more whitespace characters.  (This does not
+include newlines, however.)  Any line that does not fall in any of these three
+categories is a C<paragraph>.
 
-Lists (code, unordered, and ordered blocks) are usually marked by indentation.
-This is not required, however, it's used to mark nesting.  Be careful.  To mark
-a block as requiring indentation, use the C<indented> tag, which contains a
-reference to a hash:
+Code, unordered, and ordered blocks do not I<require> indentation, but the
+parser uses it to control nesting in lists.  Be careful.  To mark a block as
+requiring indentation, use the C<indented> tag, which contains a reference to a
+hash:
 
 	my $html = format($text, { 
 		indented    => { map { $_ => 1 } qw( ordered unordered code )}
 	});
 
 Block entries in the tag hashes must contain array references.  The first two
-items are the tags used at the start and end of the block.  As you'd expect,
-the last items contain the tags used at the start and end of each line.  Where
-there needs to be more processing of individual lines, use a subref as the
-third item.  This is how ordered lines are numbered in HTML lists:
+items are the tags used at the start and end of the block.  The last items
+contain the tags used at the start and end of each line.  Where there needs to
+be more processing of individual lines, use a subref as the third item.  This
+is how the module numbers ordered lines in HTML lists:
 
 	my $html = format($text, { ordered => [ '<ol>', "</ol>\n",
 		sub { qq|<li value="$_[2]">$_[0]</li>\n| } ] });
 
-The first argument to these subrefs is the text of the line itself, after it
-has been processed.  (The indentation and tokens used to mark this as a list
-item are removed, and the rest of the line is checked for other line
-formattings.)  The second argument is the indentation level.  The subsequent
-arguments are captured variables in the regular expression used to find this
-list type.  The regexp for ordered lists is:
+The first argument to these subrefs is the post-processed text of the line
+itself.  (Processing removes the indentation and tokens used to mark this as a
+list and checks the rest of the line for other line formattings.)  The second
+argument is the indentation level.  The subsequent arguments are captured
+variables in the regular expression used to find this list type.  The regexp
+for ordered lists is:
 
 	qr/^([\dA-Za-z]+)\.\s*/;
 
-Indentation is processed first, if applicable, and the indentation level (the
-length of the indentation removed) is stored.  The line must contain one or
-more alphanumeric character followed by a single period and optional whitespace
-to be identified as an ordered list item.  The contents of this last group, the
-value of the list item, is saved, and will be passed to the subref as the third
-argument.
+The module processes indentation first, if applicable, and stores the
+indentation level (the length of the indentation removed).  The line must
+contain one or more alphanumeric character followed by a single period and
+optional whitespace to be an ordered list item.  The module saves the contents
+of this last group, the value of the list item, and passes it to the subref as
+the third argument.
 
-Lists are automatically started and ended as necessary.
+Lists automatically start and end as necessary.
 
-Because of the indentation issue, blocks must be processed in a specific order.
-The C<blockorder> tag governs this order.  It contains a reference to an array
-of the names of the appropriate blocks to process.  If you add a block type, be
-sure to add an entry for it in C<blockorder>:
+Because of the indentation issue, there is a specific blocks processing in a
+specific order.  The C<blockorder> tag governs this order.  It contains a
+reference to an array of the names of the appropriate blocks to process.  If
+you add a block type, be sure to add an entry for it in C<blockorder>:
 
 	my $html = format($text, {
 		escaped       => [ '', '', '', '' ],
@@ -720,8 +731,8 @@ sure to add an entry for it in C<blockorder>:
 
 =head3 Finding blocks
 
-Text::WikiFormat uses regular expressions to find blocks.  These are kept in
-the %tags hash, under the C<blocks> key.  To change the regular expression to
+Text::WikiFormat uses regular expressions to find blocks.  These are in the
+C<%tags> hash under the C<blocks> key.  To change the regular expression to
 find code block items, use:
 
 	my $html     =  format($wikitext, {
@@ -746,8 +757,8 @@ C<qr/^/> instead.
 As intrepid bug reporter Tom Hukins pointed out in CPAN RT bug #671, the order
 in which Text::WikiFormat searches for blocks varies by platform and version of
 Perl.  Because some block-finding regular expressions are more specific than
-others, what's intended to be one type of block may be caught by a different
-list type.
+others, what you intend to be one type of block may turn into a different list
+type.
 
 If you're adding new block types, be aware of this.  The C<blockorder> entry in
 C<%tags> exists to force Text::WikiFormat to apply its regexes from most
@@ -755,8 +766,6 @@ specific to least specific.  It contains an array reference.  By default, it
 looks for ordered lists first, unordered lists second, and code references at
 the end.
 
-=back
-
 =head1 AUTHOR
 
 chromatic, C<chromatic@wgz.org>, with much input from the Jellybean team
@@ -765,11 +774,13 @@ many failing tests, and is usually the driving force behind new features and
 releases.  If you think this module is worth buying me a beer, she deserves at
 least half of it.  
 
+Alex Vandiver added a nice patch and tests for extended links.
+
 Tony Bowden, Tom Hukins, and Andy H. all suggested useful features that are now
 implemented.  
 
-Sam Vilain, Chris Winters, and Paul Schmidt have all found and reported silly
-bugs.
+Sam Vilain, Chris Winters, Paul Schmidt, and Art Henry have all found and
+reported silly bugs.
 
 Blame me for the implementation.
 
@@ -801,5 +812,5 @@ Matt Sergeant keeps threatening to write a nice SAX-throwing Wiki formatter.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2004, chromatic.  All rights reserved.  This module is
+Copyright (c) 2002 - 2005, chromatic.  All rights reserved.  This module is
 distributed under the same terms as Perl itself.
